#
# furl: URL manipulation made simple.
#
# Arthur Grunseid
# grunseid.com
# grunseid@gmail.com
#
# License: Build Amazing Things (Unlicense)

__title__ = 'furl'
__version__ = '0.3' # Keep synchronized with setup.py.
__author__ = 'Arthur Grunseid'
__contact__ = 'grunseid@gmail.com'
__license__ = 'Unlicense'
__url__ = 'https://github.com/gruns/furl'

from .furl import *
